==> zio-aws-ssm_2.13-5.17.130.3-sources.jar: zio/aws/ssm/model/GetOpsSummaryResponse.scala <==
package zio.aws.ssm.model
import zio.aws.ssm.model.primitives.NextToken
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class GetOpsSummaryResponse(
    entities: Option[Iterable[zio.aws.ssm.model.OpsEntity]] = None,
    nextToken: Option[NextToken] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ssm.model.GetOpsSummaryResponse = {
    import GetOpsSummaryResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ssm.model.GetOpsSummaryResponse
      .builder()
      .optionallyWith(
        entities.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.entities)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly: zio.aws.ssm.model.GetOpsSummaryResponse.ReadOnly =
    zio.aws.ssm.model.GetOpsSummaryResponse.wrap(buildAwsValue())
}
object GetOpsSummaryResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ssm.model.GetOpsSummaryResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ssm.model.GetOpsSummaryResponse =
      zio.aws.ssm.model.GetOpsSummaryResponse(
        entities.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def entities: Option[List[zio.aws.ssm.model.OpsEntity.ReadOnly]]
    def nextToken: Option[NextToken]
    def getEntities
        : ZIO[Any, AwsError, List[zio.aws.ssm.model.OpsEntity.ReadOnly]] =
      AwsError.unwrapOptionField("entities", entities)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ssm.model.GetOpsSummaryResponse
  ) extends zio.aws.ssm.model.GetOpsSummaryResponse.ReadOnly {
    override val entities: Option[List[zio.aws.ssm.model.OpsEntity.ReadOnly]] =
      scala
        .Option(impl.entities())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.ssm.model.OpsEntity.wrap(item)
          }.toList
        )
    override val nextToken: Option[NextToken] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.ssm.model.primitives.NextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ssm.model.GetOpsSummaryResponse
  ): zio.aws.ssm.model.GetOpsSummaryResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-ssm_2.13-6.20.103.1-sources.jar: zio/aws/ssm/model/GetOpsSummaryResponse.scala <==
package zio.aws.ssm.model
import zio.aws.ssm.model.primitives.NextToken
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class GetOpsSummaryResponse(
    entities: Optional[Iterable[zio.aws.ssm.model.OpsEntity]] = Optional.Absent,
    nextToken: Optional[NextToken] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ssm.model.GetOpsSummaryResponse = {
    import GetOpsSummaryResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ssm.model.GetOpsSummaryResponse
      .builder()
      .optionallyWith(
        entities.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.entities)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly: zio.aws.ssm.model.GetOpsSummaryResponse.ReadOnly =
    zio.aws.ssm.model.GetOpsSummaryResponse.wrap(buildAwsValue())
}
object GetOpsSummaryResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ssm.model.GetOpsSummaryResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ssm.model.GetOpsSummaryResponse =
      zio.aws.ssm.model.GetOpsSummaryResponse(
        entities.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def entities: Optional[List[zio.aws.ssm.model.OpsEntity.ReadOnly]]
    def nextToken: Optional[NextToken]
    def getEntities
        : ZIO[Any, AwsError, List[zio.aws.ssm.model.OpsEntity.ReadOnly]] =
      AwsError.unwrapOptionField("entities", entities)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ssm.model.GetOpsSummaryResponse
  ) extends zio.aws.ssm.model.GetOpsSummaryResponse.ReadOnly {
    override val entities
        : Optional[List[zio.aws.ssm.model.OpsEntity.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.entities())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.ssm.model.OpsEntity.wrap(item)
          }.toList
        )
    override val nextToken: Optional[NextToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.ssm.model.primitives.NextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ssm.model.GetOpsSummaryResponse
  ): zio.aws.ssm.model.GetOpsSummaryResponse.ReadOnly = new Wrapper(impl)
}
